# STRkit Rust extension

Extension for STRKit with components written in Rust, for improved performance.

&copy; the contributors of the STRkit Rust extension 2023. Licensed under
the terms of the [GNU General Public License, v3.0](./LICENSE).
